
package com.example.demonightmode;

import android.os.Bundle;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.graphics.PixelFormat;
import android.view.Gravity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup.LayoutParams;
import android.view.WindowManager;
import android.widget.TextView;

public class MainActivity extends Activity {
    private View mRootView;

    private TextView mNightView;

    private WindowManager mWindowManager;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        NightModeUtils.onActivityCreateSetTheme(this);
        setContentView(R.layout.activity_main);
        mRootView = this.findViewById(R.id.root);
        mWindowManager = (WindowManager)getSystemService(Context.WINDOW_SERVICE);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem aItem) {
        if (aItem.getItemId() == R.id.dialog) {
            AlertDialog.Builder builder = DialogBuilderFactory.createBuilder(this);
            builder.setTitle(R.string.warning)
                   .setNegativeButton(android.R.string.cancel, null)
                   .setPositiveButton(android.R.string.ok, null);
            builder.create().show();
            return true;
        }
        return super.onOptionsItemSelected(aItem);
    }

    public void onMethod1Click(View view) {
        if (view.getId() == R.id.btn_method1) {
            int theme = NightModeUtils.getSwitchDayNightMode(this);
            NightModeUtils.setBackGroundColor(this, mRootView, theme);
            NightModeUtils.setTextColor(this, findViewById(R.id.text), theme);
            NightModeUtils.setDayNightMode(this, theme);
        }
    }

    public void onMethod2Click(View view) {
        if (view.getId() == R.id.btn_method2) {
            NightModeUtils.changeToTheme(this);
        }
    }

    public void onMethod3Click(View view) {
        if (view.getId() == R.id.btn_method3) {
            int theme = NightModeUtils.getSwitchDayNightMode(this);
            if (theme == NightModeUtils.THEME_NIGHT) {
                night();
            } else {
                day();
            }
            NightModeUtils.setDayNightMode(this, theme);
        }
    }

    private void night() {
        if (mNightView == null) {
            mNightView = new TextView(this);
            mNightView.setBackgroundColor(0xaa000000);
        }

        WindowManager.LayoutParams lp = new WindowManager.LayoutParams(
                LayoutParams.MATCH_PARENT,
                LayoutParams.MATCH_PARENT,
                WindowManager.LayoutParams.TYPE_APPLICATION,
                WindowManager.LayoutParams.FLAG_NOT_TOUCHABLE | WindowManager.LayoutParams.FLAG_NOT_FOCUSABLE,
                PixelFormat.TRANSLUCENT);
        lp.gravity = Gravity.BOTTOM;
        lp.y = 10;

        try {
            mWindowManager.addView(mNightView, lp);
        } catch (Exception ex) {
        }
    }

    private void day() {
        try {
            mWindowManager.removeView(mNightView);
        } catch (Exception ex) {
        }
    }
}
